%%
%% This is file `macce.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `applemacce')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at http://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright 1993-2015
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}



  \ProvidesFile{macce.def}
   [2015/03/17 v1.2c Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textdiv}
   {\TextSymbolUnavailable\textdiv}
\DeclareInputText{128}{\"A}
\DeclareInputText{131}{\@tabacckludge'E}
\DeclareInputText{132}{\k A}
\DeclareInputText{133}{\"O}
\DeclareInputText{134}{\"U}
\DeclareInputText{136}{\k a}
\DeclareInputText{137}{\v C}
\DeclareInputText{138}{\"a}
\DeclareInputText{139}{\v c}
\DeclareInputText{140}{\@tabacckludge'C}
\DeclareInputText{141}{\@tabacckludge'c}
\DeclareInputText{143}{\@tabacckludge'Z}
\DeclareInputText{144}{\@tabacckludge'z}
\DeclareInputText{151}{\@tabacckludge'o}
\DeclareInputText{159}{\"u}
\DeclareInputText{154}{\"o}
\DeclareInputText{133}{\"O}
\DeclareInputText{134}{\"U}
\DeclareInputText{153}{\^o}
\DeclareInputText{160}{\dag}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\k E}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\S}
\DeclareInputText{165}{\textbullet}
\DeclareInputText{166}{\P}
\DeclareInputText{167}{\ss}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{171}{\k e}
\DeclareInputText{193}{\@tabacckludge'N}
\DeclareInputText{169}{\copyright}
\DeclareInputText{184}{\l}
\DeclareInputText{196}{\@tabacckludge'n}
\DeclareInputText{199}{\guillemotleft}
\DeclareInputText{200}{\guillemotright}
\DeclareInputText{201}{\dots}
\DeclareInputText{202}{\nobreakspace}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputText{214}{\textdiv}
\DeclareInputText{220}{\guilsinglleft}
\DeclareInputText{221}{\guilsinglright}
\DeclareInputText{222}{\v r}
\DeclareInputText{226}{\quotesinglbase}
\DeclareInputText{227}{\quotedblbase}
\DeclareInputText{229}{\@tabacckludge'S}
\DeclareInputText{230}{\@tabacckludge's}
\DeclareInputText{238}{\@tabacckludge'O}
\DeclareInputText{239}{\^O}
\DeclareInputText{251}{\.Z}
\DeclareInputText{252}{\L}
\DeclareInputText{253}{\.z}
\endinput
%%
%% End of file `macce.def'.
