%%
%% This is file `latin9.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `latin9')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at http://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright 1993-2015
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}



 \ProvidesFile{latin9.def}
   [2015/03/17 v1.2c Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\texteuro}
   {\TextSymbolUnavailable\texteuro}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
\DeclareInputText{164}{\texteuro}
\DeclareInputText{166}{\v S}
\DeclareInputText{168}{\v s}
\DeclareInputText{180}{\v Z}
\DeclareInputText{184}{\v z}
\DeclareInputText{188}{\OE}
\DeclareInputText{189}{\oe}
\DeclareInputText{190}{\"Y}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{161}{\textexclamdown}
\DeclareInputMath{177}{\pm}
\DeclareInputText{162}{\textcent}
\DeclareInputMath{178}{\mathtwosuperior}
\DeclareInputText{163}{\pounds}
\DeclareInputMath{179}{\maththreesuperior}
\DeclareInputText{165}{\textyen}
\DeclareInputMath{181}{\mu}
\DeclareInputText{182}{\P}
\DeclareInputText{167}{\S}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{169}{\copyright}
\DeclareInputMath{185}{\mathonesuperior}
\DeclareInputText{170}{\textordfeminine}
\DeclareInputText{186}{\textordmasculine}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputText{187}{\guillemotright}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\@tabacckludge={}}
\DeclareInputText{191}{\textquestiondown}
\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{208}{\DH}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{209}{\~N}
\DeclareInputText{194}{\^A}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{195}{\~A}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{196}{\"A}
\DeclareInputText{212}{\^O}
\DeclareInputText{197}{\r A}
\DeclareInputText{213}{\~O}
\DeclareInputText{198}{\AE}
\DeclareInputText{214}{\"O}
\DeclareInputText{199}{\c C}
\DeclareInputMath{215}{\times}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{216}{\O}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{202}{\^E}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{203}{\"E}
\DeclareInputText{219}{\^U}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{220}{\"U}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{206}{\^I}
\DeclareInputText{222}{\TH}
\DeclareInputText{207}{\"I}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{240}{\dh}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{241}{\~n}
\DeclareInputText{226}{\^a}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{227}{\~a}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{228}{\"a}
\DeclareInputText{244}{\^o}
\DeclareInputText{229}{\r a}
\DeclareInputText{245}{\~o}
\DeclareInputText{230}{\ae}
\DeclareInputText{246}{\"o}
\DeclareInputText{231}{\c c}
\DeclareInputMath{247}{\div}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{248}{\o}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{234}{\^e}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{235}{\"e}
\DeclareInputText{251}{\^u}
\DeclareInputText{236}{\@tabacckludge`\i}
\DeclareInputText{252}{\"u}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{238}{\^\i}
\DeclareInputText{254}{\th}
\DeclareInputText{239}{\"\i}
\DeclareInputText{255}{\"y}
\endinput
%%
%% End of file `latin9.def'.
